@@ -56,7 +56,7 @@ class Population:
         police = []
         complete = 0
         for i in range(immune):
-            police.append(sorted(self.birds, key=lambda x: x.fitness)[-i])
+            police.append(copy.deepcopy(sorted(self.birds, key=lambda x: x.fitness)[-i]))
             complete += 1
         for bird in self.birds:
             complete += 1
